package mediarange_test

import (
	"sourcecode.social/reiver/go-httpaccept/mediarange"

	"testing"
)

func TestMediaRange_Type(t *testing.T) {

	tests := []struct{
		MediaRange mediarange.MediaRange
		Expected string
	}{
		{
			MediaRange: mediarange.Create(""  ,  ""),
			Expected:                     "*",
		},



		{
			MediaRange: mediarange.Create("*"  ,  "*"),
			Expected:                     "*",
		},



		{
			MediaRange: mediarange.Create("application"  ,  ""),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  ""),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("font"  ,  ""),
			Expected:                     "font",
		},
		{
			MediaRange: mediarange.Create("image"  ,  ""),
			Expected:                     "image",
		},
		{
			MediaRange: mediarange.Create("text"  ,  ""),
			Expected:                     "text",
		},
		{
			MediaRange: mediarange.Create("video"  ,  ""),
			Expected:                     "video",
		},
		{
			MediaRange: mediarange.Create("xyz"  ,  ""),
			Expected:                     "xyz",
		},



		{
			MediaRange: mediarange.Create("application"  ,  "*"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "*"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("font"  ,  "*"),
			Expected:                     "font",
		},
		{
			MediaRange: mediarange.Create("image"  ,  "*"),
			Expected:                     "image",
		},
		{
			MediaRange: mediarange.Create("text"  ,  ""),
			Expected:                     "text",
		},
		{
			MediaRange: mediarange.Create("video"  ,  ""),
			Expected:                     "video",
		},
		{
			MediaRange: mediarange.Create("xyz"  ,  ""),
			Expected:                     "xyz",
		},



		{
			MediaRange: mediarange.Create("Application"  ,  "*"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("Audio"  ,  "*"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("Font"  ,  "*"),
			Expected:                     "font",
		},
		{
			MediaRange: mediarange.Create("Image"  ,  "*"),
			Expected:                     "image",
		},
		{
			MediaRange: mediarange.Create("Text"  ,  ""),
			Expected:                     "text",
		},
		{
			MediaRange: mediarange.Create("Video"  ,  ""),
			Expected:                     "video",
		},
		{
			MediaRange: mediarange.Create("Xyz"  ,  ""),
			Expected:                     "xyz",
		},



		{
			MediaRange: mediarange.Create("APPLICATION"  ,  "*"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("AUDIO"  ,  "*"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("FONT"  ,  "*"),
			Expected:                     "font",
		},
		{
			MediaRange: mediarange.Create("IMAGE"  ,  "*"),
			Expected:                     "image",
		},
		{
			MediaRange: mediarange.Create("TEXT"  ,  ""),
			Expected:                     "text",
		},
		{
			MediaRange: mediarange.Create("VIDEO"  ,  ""),
			Expected:                     "video",
		},
		{
			MediaRange: mediarange.Create("XYZ"  ,  ""),
			Expected:                     "xyz",
		},



		{
			MediaRange: mediarange.Create("application"  ,  "activity+json"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "epub+zip"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "gzip"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "java-archive"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "json"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "ld+json"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "pdf"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "msword"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "octet-stream"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "ogg"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "rtf"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "vnd.oasis.opendocument.spreadsheet"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "vnd.openxmlformats-officedocument.wordprocessingml.document"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "vnd.mozilla.xul+xml"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "vnd.ms-excel"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-7z-compressed"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-bzip"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-bzip2"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-cdf"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-csh"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-freearc"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-httpd-php"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-sh"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-tar"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "xhtml+xml"),
			Expected:                     "application",
		},



		{
			MediaRange: mediarange.Create("audio"  ,  "aac"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "midi"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "mpeg"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "ogg"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "opus"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "wav"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "webm"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "3gpp"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "3gpp2"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "x-midi"),
			Expected:                     "audio",
		},



		{
			MediaRange: mediarange.Create("font"  ,  "ttf"),
			Expected:                     "font",
		},



		{
			MediaRange: mediarange.Create("image"  ,  "avif"),
			Expected:                     "image",
		},
		{
			MediaRange: mediarange.Create("image"  ,  "bmp"),
			Expected:                     "image",
		},
		{
			MediaRange: mediarange.Create("image"  ,  "gif"),
			Expected:                     "image",
		},
		{
			MediaRange: mediarange.Create("image"  ,  "png"),
			Expected:                     "image",
		},
		{
			MediaRange: mediarange.Create("image"  ,  "tiff"),
			Expected:                     "image",
		},



		{
			MediaRange: mediarange.Create("text"  ,  "css"),
			Expected:                     "text",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "csv"),
			Expected:                     "text",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "html"),
			Expected:                     "text",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "javascript"),
			Expected:                     "text",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "markdown"),
			Expected:                     "text",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "plain"),
			Expected:                     "text",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "x-markdown"),
			Expected:                     "text",
		},



		{
			MediaRange: mediarange.Create("video"  ,  "3gpp2"),
			Expected:                     "video",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "ogg"),
			Expected:                     "video",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "mp2t"),
			Expected:                     "video",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "mp4"),
			Expected:                     "video",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "mpeg"),
			Expected:                     "video",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "webm"),
			Expected:                     "video",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "x-msvideo"),
			Expected:                     "video",
		},



		{
			MediaRange: mediarange.Create("application"  ,  "ACTIVITY+JSON"),
			Expected:                     "application",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "MPEG"),
			Expected:                     "audio",
		},
		{
			MediaRange: mediarange.Create("font"  ,  "TTF"),
			Expected:                     "font",
		},
		{
			MediaRange: mediarange.Create("image"  ,  "PNG"),
			Expected:                     "image",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "HTML"),
			Expected:                     "text",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "OGG"),
			Expected:                     "video",
		},
		{
			MediaRange: mediarange.Create("xyz"  ,  "BANANA"),
			Expected:                     "xyz",
		},
	}

	for testNumber, test := range tests {

		actual := test.MediaRange.Type()
		expected := test.Expected

		if expected != actual {
			t.Errorf("For test #%d, the actual canonical-type is not what was expected.", testNumber)
			t.Logf("MEDIA-RANGEE: %#v", test.MediaRange)
			t.Logf("EXPECTED: %q", expected)
			t.Logf("ACTUAL:   %q", actual)
			continue
		}
	}
}
